@@ -94,8 +94,8 @@ matchBindings ((BiMeta name) : pbs) tbs scope =
   let splits = [splitAt idx tbs | idx <- [0 .. length tbs]]
    in catMaybes
         [ combine (substSingle name (MvBindings before)) subst
-          | (before, after) <- splits,
-            subst <- matchBindings pbs after scope
+        | (before, after) <- splits
+        , subst <- matchBindings pbs after scope
         ]
 matchBindings (pb : pbs) (tb : tbs) scope = combineMany (matchBinding pb tb scope) (matchBindings pbs tbs scope)
 matchBindings _ _ _ = []
@@ -139,11 +139,17 @@ matchExpression (ExApplication pexp pbd) (ExApplication texp tbd) scope = combin
 matchExpression (ExMetaTail exp meta) tgt scope = case tailExpressions exp tgt scope of
   ([], _) -> []
   (substs, tails) -> combineMany substs [substSingle meta (MvTail tails)]
+matchExpression (ExPhiAgain prefix idx expr) (ExPhiAgain prefix' idx' expr') scope
+  | prefix == prefix' && idx == idx' = matchExpression expr expr' scope
+  | otherwise = []
+matchExpression (ExPhiMeet prefix idx expr) (ExPhiMeet prefix' idx' expr') scope
+  | prefix == prefix' && idx == idx' = matchExpression expr expr' scope
+  | otherwise = []
 matchExpression _ _ _ = []
 
 -- Deep match pattern to expression inside binding
 matchBindingExpression :: Binding -> Expression -> Expression -> [Subst]
-matchBindingExpression (BiTau _ texp) ptn scope = matchExpressionDeep ptn texp scope
+matchBindingExpression (BiTau _ exp) ptn scope = matchExpressionDeep ptn exp scope
 matchBindingExpression _ _ _ = []
 
 -- Match expression with deep nested expression(s) matching
@@ -151,11 +157,11 @@ matchExpressionDeep :: Expression -> Expression -> Expression -> [Subst]
 matchExpressionDeep ptn tgt scope =
   let matched = matchExpression ptn tgt scope
       deep = case tgt of
-        ExFormation bds -> concatMap (\bd -> matchBindingExpression bd ptn (ExFormation bds)) bds
+        ExFormation bds -> concatMap (\bd -> matchBindingExpression bd ptn tgt) bds
         ExDispatch exp _ -> matchExpressionDeep ptn exp scope
         ExApplication exp tau -> matchExpressionDeep ptn exp scope ++ matchBindingExpression tau ptn scope
         _ -> []
    in matched ++ deep
 
 matchProgram :: Expression -> Program -> [Subst]
-matchProgram ptn (Program exp) = matchExpressionDeep ptn exp defaultScope
\ No newline at end of file
+matchProgram ptn (Program exp) = matchExpressionDeep ptn exp defaultScope
