@@ -7,14 +7,14 @@
 -- SPDX-License-Identifier: MIT
 
 module XMIR
-  ( programToXMIR,
-    printXMIR,
-    toName,
-    parseXMIR,
-    parseXMIRThrows,
-    xmirToPhi,
-    defaultXmirContext,
-    XmirContext (XmirContext),
+  ( programToXMIR
+  , printXMIR
+  , toName
+  , parseXMIR
+  , parseXMIRThrows
+  , xmirToPhi
+  , defaultXmirContext
+  , XmirContext (XmirContext)
   )
 where
 
@@ -45,9 +45,9 @@ import Text.XML
 import qualified Text.XML.Cursor as C
 
 data XmirContext = XmirContext
-  { omitListing :: Bool,
-    omitComments :: Bool,
-    listing :: Program -> String
+  { omitListing :: Bool
+  , omitComments :: Bool
+  , listing :: Program -> String
   }
 
 defaultXmirContext :: XmirContext
@@ -62,11 +62,11 @@ data XMIRException
   deriving (Exception)
 
 instance Show XMIRException where
-  show UnsupportedProgram {..} = printf "XMIR does not support such program:\n%s" (printProgram prog)
-  show UnsupportedExpression {..} = printf "XMIR does not support such expression:\n%s" (printExpression expr)
-  show UnsupportedBinding {..} = printf "XMIR does not support such bindings: %s" (printBinding binding)
-  show CouldNotParseXMIR {..} = printf "Couldn't parse given XMIR, cause: %s" message
-  show InvalidXMIRFormat {..} =
+  show UnsupportedProgram{..} = printf "XMIR does not support such program:\n%s" (printProgram prog)
+  show UnsupportedExpression{..} = printf "XMIR does not support such expression:\n%s" (printExpression expr)
+  show UnsupportedBinding{..} = printf "XMIR does not support such bindings: %s" (printBinding binding)
+  show CouldNotParseXMIR{..} = printf "Couldn't parse given XMIR, cause: %s" message
+  show InvalidXMIRFormat{..} =
     printf
       "Couldn't traverse though given XMIR, cause: %s\nXMIR:\n%s"
       message
@@ -102,32 +102,32 @@ expression (ExDispatch expr attr) ctx = do
       if head base == '.' || not (null children)
         then pure ('.' : attr', [object [("base", base)] children])
         else pure (base ++ ('.' : attr'), children)
-expression (DataNumber bytes) XmirContext {..} =
+expression (DataNumber bytes) XmirContext{..} =
   let bts =
         object
           [("as", printAttribute (AtAlpha 0)), ("base", "Φ.org.eolang.bytes")]
           [object [] [NodeContent (T.pack (printBytes bytes))]]
    in pure
-        ( "Φ.org.eolang.number",
-          if omitComments
+        ( "Φ.org.eolang.number"
+        , if omitComments
             then [bts]
             else
-              [ NodeComment (T.pack (either show show (btsToNum bytes))),
-                bts
+              [ NodeComment (T.pack (either show show (btsToNum bytes)))
+              , bts
               ]
         )
-expression (DataString bytes) XmirContext {..} =
+expression (DataString bytes) XmirContext{..} =
   let bts =
         object
           [("as", printAttribute (AtAlpha 0)), ("base", "Φ.org.eolang.bytes")]
           [object [] [NodeContent (T.pack (printBytes bytes))]]
    in pure
-        ( "Φ.org.eolang.string",
-          if omitComments
+        ( "Φ.org.eolang.string"
+        , if omitComments
             then [bts]
             else
-              [ NodeComment (T.pack ('"' : btsToStr bytes ++ "\"")),
-                bts
+              [ NodeComment (T.pack ('"' : btsToStr bytes ++ "\""))
+              , bts
               ]
         )
 expression (ExApplication expr (BiTau attr texpr)) ctx = do
@@ -164,7 +164,7 @@ nestedBindings :: [Binding] -> XmirContext -> IO [Node]
 nestedBindings bds ctx = catMaybes <$> mapM (`formationBinding` ctx) bds
 
 programToXMIR :: Program -> XmirContext -> IO Document
-programToXMIR prog@(Program expr@(ExFormation [BiTau (AtLabel _) arg, BiVoid AtRho])) ctx@XmirContext {..} = case arg of
+programToXMIR prog@(Program expr@(ExFormation [BiTau (AtLabel _) arg, BiVoid AtRho])) ctx@XmirContext{..} = case arg of
   ExFormation _ -> programToXMIR'
   ExApplication _ _ -> programToXMIR'
   ExDispatch _ _ -> programToXMIR'
@@ -188,13 +188,13 @@ programToXMIR prog@(Program expr@(ExFormation [BiTau (AtLabel _) arg, BiVoid AtR
             (Prologue [] Nothing [])
             ( element
                 "object"
-                [ ("dob", formatTime defaultTimeLocale "%Y-%m-%dT%H:%M:%S" now),
-                  ("ms", "0"),
-                  ("revision", "1234567"),
-                  ("time", time now),
-                  ("version", showVersion version),
-                  ("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance"),
-                  ("xsi:noNamespaceSchemaLocation", "https://raw.githubusercontent.com/objectionary/eo/refs/heads/gh-pages/XMIR.xsd")
+                [ ("dob", formatTime defaultTimeLocale "%Y-%m-%dT%H:%M:%S" now)
+                , ("ms", "0")
+                , ("revision", "1234567")
+                , ("time", time now)
+                , ("version", showVersion version)
+                , ("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance")
+                , ("xsi:noNamespaceSchemaLocation", "https://raw.githubusercontent.com/objectionary/eo/refs/heads/gh-pages/XMIR.xsd")
                 ]
                 ( if null pckg
                     then [listing', root]
@@ -241,9 +241,9 @@ programToXMIR prog@(Program expr@(ExFormation [BiTau (AtLabel _) arg, BiVoid AtR
                 ( element
                     "meta"
                     []
-                    [ NodeElement (element "head" [] [NodeContent (T.pack "package")]),
-                      NodeElement (element "tail" [] [NodeContent (T.pack pckg)]),
-                      NodeElement (element "part" [] [NodeContent (T.pack pckg)])
+                    [ NodeElement (element "head" [] [NodeContent (T.pack "package")])
+                    , NodeElement (element "tail" [] [NodeContent (T.pack pckg)])
+                    , NodeElement (element "part" [] [NodeContent (T.pack pckg)])
                     ]
                 )
             ]
@@ -308,7 +308,7 @@ printElement indentLevel (Element name attrs nodes) eol
     attrsText =
       mconcat
         [ TB.fromString " " <> TB.fromText (nameLocalName k) <> TB.fromString "=\"" <> TB.fromText v <> TB.fromString "\""
-          | (k, v) <- M.toList attrs
+        | (k, v) <- M.toList attrs
         ]
 
     isTextNode (NodeContent _) = True
@@ -361,11 +361,11 @@ xmirToPhi xmir =
                 _ -> throwIO (InvalidXMIRFormat "Expected single <o> element in <object>" doc)
               let pckg =
                     [ T.unpack t
-                      | meta <- doc C.$/ C.element (toName "metas") C.&/ C.element (toName "meta"),
-                        let heads = meta C.$/ C.element (toName "head") C.&/ C.content,
-                        heads == ["package"],
-                        tail' <- meta C.$/ C.element (toName "tail") C.&/ C.content,
-                        t <- T.splitOn "." tail'
+                    | meta <- doc C.$/ C.element (toName "metas") C.&/ C.element (toName "meta")
+                    , let heads = meta C.$/ C.element (toName "head") C.&/ C.content
+                    , heads == ["package"]
+                    , tail' <- meta C.$/ C.element (toName "tail") C.&/ C.content
+                    , t <- T.splitOn "." tail'
                     ]
               if null pckg
                 then pure (Program (ExFormation [obj, BiVoid AtRho]))
@@ -446,7 +446,7 @@ xmirToExpression cur fqn
 xmirToApplication :: Expression -> [C.Cursor] -> [String] -> IO Expression
 xmirToApplication = xmirToApplication' 0
   where
-    xmirToApplication' :: Integer -> Expression -> [C.Cursor] -> [String] -> IO Expression
+    xmirToApplication' :: Int -> Expression -> [C.Cursor] -> [String] -> IO Expression
     xmirToApplication' _ expr [] _ = pure expr
     xmirToApplication' idx expr (arg : args) fqn = do
       let app
@@ -467,7 +467,7 @@ xmirToApplication = xmirToApplication' 0
       app' <- app
       xmirToApplication' (idx + 1) app' args fqn
 
-    asToAttr :: C.Cursor -> Integer -> IO Attribute
+    asToAttr :: C.Cursor -> Int -> IO Attribute
     asToAttr cur idx
       | hasAttr "as" cur = do
           as <- getAttr "as" cur
@@ -480,7 +480,7 @@ xmirToApplication = xmirToApplication' 0
 toAttr :: String -> C.Cursor -> IO Attribute
 toAttr attr cur = case attr of
   'α' : rest' ->
-    case TR.readMaybe rest' :: Maybe Integer of
+    case TR.readMaybe rest' :: Maybe Int of
       Just idx -> pure (AtAlpha idx)
       Nothing -> throwIO (InvalidXMIRFormat "The attribute started with 'α' must be followed by integer" cur)
   "φ" -> pure AtPhi
